<?php
/*=================================================
	Project: phpGedView
	File: clippings.php
	Author: John Finlay
	Input Variables: $action, $id, $type
	Comments:
		A cart with shopping cart type features for taking clippings from
		the GEDCOM file and creating a GEDCOM file for downloading.

	Change Log:
		7/10/02 - File Created
		9/24/02 - added support for language files

===================================================*/
// -- include config file
require("config.php");

if (!isset($action)) $action="";

// -- print html header information
print_header($pgv_lang["clip_cart"]);
print "\r\n\t<h2>".$pgv_lang["clippings_cart"]."</h2>";
print $pgv_lang["clip_explaination"];

function same_group($a, $b) {
	if ($a['type']==$b['type']) return strnatcasecmp($a['id'], $b['id']);
	if ($a['type']=='source') return 1;
	if ($a['type']=='indi') return -1;
	if ($b['type']=='source') return -1;
	if ($b['type']=='indi') return 1;
	return 0;
}

function id_in_cart($id) {
	global $cart;
	$ct = count($cart);
	for($i=0; $i<$ct; $i++) {
		$temp = $cart[$i];
		if ($temp['id']==$id) {
			return true;
		}
	}
	return false;
}

function add_clipping($clipping) {
	global $cart, $pgv_lang;
	if (($clipping['id']==false)||($clipping['id']=="")) return;
	$ct = count($cart);
	if (!id_in_cart($clipping['id'])) {
		$cart[$ct]=$clipping;
		$gedrec = find_gedcom_record($clipping['id']);
		$st = preg_match_all("/\d SOUR @(.*)@/", $gedrec, $match, PREG_SET_ORDER);
		for($i=0; $i<$st; $i++) {
			$clipping = array();
			$clipping['type']="source";
			$clipping['id']=$match[$i][1];
			$ct = count($cart);
			if (!id_in_cart($clipping['id'])) {
				$cart[$ct]=$clipping;
			}
		}
		$nt = preg_match_all("/\d NOTE @(.*)@/", $gedrec, $match, PREG_SET_ORDER);
		for($i=0; $i<$nt; $i++) {
			$clipping = array();
			$clipping['type']="note";
			$clipping['id']=$match[$i][1];
			$ct = count($cart);
			if (!id_in_cart($clipping['id'])) {
				$cart[$ct]=$clipping;
			}
		}
	}
}

// --------------------------------- Recursive function to traverse the tree
function add_family_descendancy($famid) {
	global $cart;

	if (!$famid) return;
	$parents = find_parents($famid);
	$clipping = array();
	$clipping['type']="indi";
	$clipping['id']=$parents["HUSB"];
	add_clipping($clipping);
	$clipping = array();
	$clipping['type']="indi";
	$clipping['id']=$parents["WIFE"];
	add_clipping($clipping);
	$famrec = find_family_record($famid);
	if ($famrec) {
		$num = preg_match_all("/1\s*CHIL\s*@(.*)@/", $famrec, $smatch,PREG_SET_ORDER);
		for($i=0; $i<$num; $i++) {
			$cfamid = find_sfamily_id($smatch[$i][1]);
			if ($cfamid) {
				$clipping = array();
				$clipping['type']="fam";
				$clipping['id']=$cfamid;
				add_clipping($clipping);		// add the childs family
				add_family_descendancy($cfamid);	// recurse on the childs family
			}
			else {
				$clipping = array();
				$clipping['type']="indi";
				$clipping['id']=$smatch[$i][1];
				add_clipping($clipping);
			}
		}
	}
}

function add_family_members($famid) {
	global $cart;
	$parents = find_parents($famid);
	$clipping = array();
	$clipping['type']="indi";
	$clipping['id']=$parents["HUSB"];
	add_clipping($clipping);
	$clipping = array();
	$clipping['type']="indi";
	$clipping['id']=$parents["WIFE"];
	add_clipping($clipping);
	$famrec = find_family_record($famid);
	if ($famrec) {
		$num = preg_match_all("/1\s*CHIL\s*@(.*)@/", $famrec, $smatch,PREG_SET_ORDER);
		for($i=0; $i<$num; $i++) {
			$clipping = array();
			$clipping['type']="indi";
			$clipping['id']=$smatch[$i][1];
			add_clipping($clipping);
		}
	}
}

//-- recursively adds direct-line ancestors to cart
function add_ancestors($pid) {
	global $cart;
	$famid = find_family_id($pid);
	if ($famid) {
		$clipping = array();
		$clipping['type']="fam";
		$clipping['id']=$famid;
		add_clipping($clipping);
		$parents = find_parents($famid);
		$clipping = array();
		$clipping['type']="indi";
		$clipping['id']=$parents["HUSB"];
		add_clipping($clipping);
		add_ancestors($parents["HUSB"]);
		$clipping = array();
		$clipping['type']="indi";
		$clipping['id']=$parents["WIFE"];
		add_clipping($clipping);
		add_ancestors($parents["WIFE"]);
	}
}

//-- recursively adds direct-line ancestors and their families to the cart
function add_ancestors_families($pid) {
	global $cart;
	$famid = find_family_id($pid);
	if ($famid) {
		$clipping = array();
		$clipping['type']="fam";
		$clipping['id']=$famid;
		add_clipping($clipping);
		$parents = find_parents($famid);
		$clipping = array();
		$clipping['type']="indi";
		$clipping['id']=$parents["HUSB"];
		add_clipping($clipping);
		add_ancestors_families($parents["HUSB"]);
		$clipping = array();
		$clipping['type']="indi";
		$clipping['id']=$parents["WIFE"];
		add_clipping($clipping);
		add_ancestors_families($parents["WIFE"]);
		$famrec = find_family_record($famid);
		if ($famrec) {
			$num = preg_match_all("/1\s*CHIL\s*@(.*)@/", $famrec, $smatch,PREG_SET_ORDER);
			for($i=0; $i<$num; $i++) {
				$clipping = array();
				$clipping['type']="indi";
				$clipping['id']=$smatch[$i][1];
				add_clipping($clipping);
			}
		}
	}
}

//---------------------------- End function definition

if ($action=='add') {
	if ($type=='fam') {
		print "\r\n<form action=\"clippings.php\" method=\"get\">\r\n".$pgv_lang["which_links"]."<br />";
		print "\r\n\t<input type=\"hidden\" name=\"id\" value=\"$id\">";
		print "\r\n\t<input type=\"hidden\" name=\"type\" value=\"$type\">";
		print "\r\n\t<input type=\"hidden\" name=\"action\" value=\"add1\">";
		print "\r\n\t<input type=\"radio\" name=\"others\" value=\"none\">".$pgv_lang["just_family"]."<br />";
		print "\r\n\t<input type=\"radio\" name=\"others\" value=\"parents\">".$pgv_lang["parents_and_family"]."<br />";
		print "\r\n\t<input type=\"radio\" name=\"others\" selected value=\"members\">".$pgv_lang["parents_and_child"]."<br />";
		print "\r\n\t<input type=\"radio\" name=\"others\" value=\"descendants\">".$pgv_lang["parents_desc"]."<br />";
		print "\r\n\t<input type=\"submit\" value=\"".$pgv_lang["continue"]."\"><br />\r\n\t</form>";
	}
	else if ($type=='indi') {
		print "\r\n<form action=\"clippings.php\" method=\"get\">\r\n".$pgv_lang["which_p_links"]."<br />";
		print "\r\n\t<input type=\"hidden\" name=\"id\" value=\"$id\">";
		print "\r\n\t<input type=\"hidden\" name=\"type\" value=\"$type\">";
		print "\r\n\t<input type=\"hidden\" name=\"action\" value=\"add1\">";
		print "\r\n\t<input type=\"radio\" name=\"others\" value=\"none\">".$pgv_lang["just_person"]."<br />";
		print "\r\n\t<input type=\"radio\" name=\"others\" value=\"parents\">".$pgv_lang["person_parents_sibs"]."<br />";
		print "\r\n\t<input type=\"radio\" name=\"others\" value=\"ancestors\">".$pgv_lang["person_ancestors"]."<br />";
		print "\r\n\t<input type=\"radio\" name=\"others\" value=\"ancestorsfamilies\">".$pgv_lang["person_ancestor_fams"]."<br />";
		print "\r\n\t<input type=\"radio\" name=\"others\" selected value=\"members\">".$pgv_lang["person_spouse"]."<br />";
		print "\r\n\t<input type=\"radio\" name=\"others\" value=\"descendants\">".$pgv_lang["person_desc"]."<br />";
		print "\r\n\t<input type=\"submit\" value=\"".$pgv_lang["continue"]."\"><br />\r\n\t</form>";
	}
	else {
		$action=='add1';
	}
}

if ($action=='add1') {
	$clipping = array();
	$clipping['type']=$type;
	$clipping['id']=$id;
	add_clipping($clipping);
	if ($type=='fam') {
		if ($others=='parents') {
			$parents = find_parents($id);
			$clipping = array();
			$clipping['type']="indi";
			$clipping['id']=$parents["HUSB"];
			add_clipping($clipping);
			$clipping = array();
			$clipping['type']="indi";
			$clipping['id']=$parents["WIFE"];
			add_clipping($clipping);
		}
		else if ($others=="members") {
			add_family_members($id);
		}
		else if ($others=="descendants") {
			add_family_descendancy($id);
		}
	}
	else if ($type=='indi') {
		if ($others=='parents') {
			$famid = find_family_id($id);
			if ($famid) {
				$clipping = array();
				$clipping['type']="fam";
				$clipping['id']=$famid;
				add_clipping($clipping);
				add_family_members($famid);
			}
		}
		else if ($others=='ancestors') {
			add_ancestors($id);
		}
		else if ($others=='ancestorsfamilies') {
			add_ancestors_families($id);
		}
		else if ($others=='members') {
			$famid = find_sfamily_id($id);
			if ($famid) {
				$clipping = array();
				$clipping['type']="fam";
				$clipping['id']=$famid;
				add_clipping($clipping);
				add_family_members($famid);
			}
		}
		else if ($others=='descendants') {
			$famid = find_sfamily_id($id);
			if ($famid) {
				$clipping = array();
				$clipping['type']="fam";
				$clipping['id']=$famid;
				add_clipping($clipping);
				add_family_descendancy($famid);
			}
		}
	}
}
else if($action=='remove') {
	$ct = count($cart);
	for($i=$item+1; $i<$ct; $i++) {
		$cart[$i-1] = $cart[$i];
	}
	unset($cart[$ct-1]);
}
else if($action=='empty') {
	$cart = array();
}
else if($action=='download') {
	$path = substr($PHP_SELF, 0, strrpos($PHP_SELF, "/")+1);
	usort($cart, "same_group");
	$media = array();
	$mediacount=0;
	$ct = count($cart);
	$filetext = "0 HEAD\r\n1 SOUR phpGedView\r\n2 NAME phpGedView\r\n2 VERS $VERSION\r\n2 CORP PhpGedView\r\n1 DEST DISKETTE\r\n1 DATE 28 JUL 2001\r\n1 FILE clipping.ged\r\n1 GEDC\r\n2 VERS 5.5\r\n2 FORM LINEAGE-LINKED\r\n1 CHAR $CHARACTER_SET\r\n";
	for($i=0; $i<$ct; $i++) {
		$clipping = $cart[$i];
		$record = find_gedcom_record($clipping['id']);
		if ($clipping['type']=='indi') {
			if (displayDetails($record)) {
				$ft = preg_match_all("/1 FAMC @(.*)@/", $record, $match, PREG_SET_ORDER);
				for ($k=0; $k<$ft; $k++) {
					if (!id_in_cart($match[$k][1])) {
						$record = preg_replace("/1 FAMC @".$match[$k][1]."@.*/", "", $record);
					}
				}
				$ft = preg_match_all("/1 FAMS @(.*)@/", $record, $match, PREG_SET_ORDER);
				for ($k=0; $k<$ft; $k++) {
					if (!id_in_cart($match[$k][1])) {
						$record = preg_replace("/1 FAMS @".$match[$k][1]."@.*/", "", $record);
					}
				}
				$ft = preg_match_all("/\d FILE (.*)/", $record, $match, PREG_SET_ORDER);
				for ($k=0; $k<$ft; $k++) {
					$filename = substr($match[$k][1], strrpos($match[$k][1], "\\")+1);
					$media[$mediacount]=$filename;
					$mediacount++;
					$record = preg_replace("|(\d FILE )".addslashes($match[$k][1])."|", "$1".$filename, $record);
				}
				$record = preg_replace("/(\r?\n)+/", "$1", $record);
				$filetext .= trim($record)."\r\n";
			}
			else {
				$filetext .= "0 @".$clipping['id']."@ INDI\r\n";
				$lines = preg_split("/\r?\n/", $record);
				for ($j=0; $j<count($lines); $j++) {
					if (strstr($lines[$j], "1 NAME")) {
						$k=$j+1;
						$filetext .= $lines[$j]."\r\n";
						while($lines[$k]{0}>1) {
							$filetext .= $lines[$k]."\r\n";
							$k++;
						}
						break;
					}
				}
				$filetext .= "1 NOTE ".$pgv_lang["person_private"]."\r\n";
			}
			$filetext .= "1 SOUR @SPGV1@\r\n";
			$filetext .= "2 PAGE http://".$_SERVER["HTTP_HOST"].$path."individual.php?pid=".$clipping['id']."\r\n";
			$filetext .= "2 DATA\r\n";
			$filetext .= "3 TEXT This Individual was downloaded from:\r\n";
			$filetext .= "4 CONT http://".$_SERVER["HTTP_HOST"].$path."individual.php?pid=".$clipping['id']."\r\n";
		}
		else if ($clipping['type']=='fam') {
			$ft = preg_match_all("/1 CHIL @(.*)@/", $record, $match, PREG_SET_ORDER);
			for ($k=0; $k<$ft; $k++) {
				if (!id_in_cart($match[$k][1])) {
					$record = preg_replace("/1 CHIL @".$match[$k][1]."@.*/", "", $record);
				}
			}
			$ft = preg_match_all("/1 HUSB @(.*)@/", $record, $match, PREG_SET_ORDER);
			for ($k=0; $k<$ft; $k++) {
				if (!id_in_cart($match[$k][1])) {
					$record = preg_replace("/1 HUSB @".$match[$k][1]."@.*/", "", $record);
				}
			}
			$ft = preg_match_all("/1 WIFE @(.*)@/", $record, $match, PREG_SET_ORDER);
			for ($k=0; $k<$ft; $k++) {
				if (!id_in_cart($match[$k][1])) {
					$record = preg_replace("/1 WIFE @".$match[$k][1]."@.*/", "", $record);
				}
			}
			$ft = preg_match_all("/\d FILE (.*)/", $record, $match, PREG_SET_ORDER);
			for ($k=0; $k<$ft; $k++) {
				$filename = substr($match[$k][1], strrpos($match[$k][1], "\\")+1);
				$media[$mediacount]=$filename;
				$mediacount++;
				$record = preg_replace("/(\d FILE )".addslashes($match[$k][1])."/", "$1".$filename, $record);
			}
			$record = preg_replace("/(\r?\n)+/", "$1", $record);
			$filetext .= trim($record)."\r\n";
			$filetext .= "1 SOUR @SPGV1@\r\n";
			$filetext .= "2 PAGE http://".$_SERVER["HTTP_HOST"].$path."family.php?famid=".$clipping['id']."\r\n";
			$filetext .= "2 DATA\r\n";
			$filetext .= "3 TEXT This Family was downloaded from:\r\n";
			$filetext .= "4 CONT http://".$_SERVER["HTTP_HOST"].$path."family.php?famid=".$clipping['id']."\r\n";
		}
		else $filetext .= trim($record)."\r\n";
		//print $record;
		if($clipping['type']=="source") {
			$st = preg_match_all("/\d REPO @(.*)@/", $record, $match, PREG_SET_ORDER);
			for($j=0; $j<$st; $j++) {
				$reporec = find_gedcom_record($match[$j][1]);
				$filetext .= $reporec;
			}
			$filetext .= "1 NOTE This Source was downloaded from:\r\n";
			$filetext .= "2 CONT http://".$_SERVER["HTTP_HOST"].$path."source.php?sid=".$clipping['id']."\r\n";
		}
	}
	$filetext .= "0 @SPGV1@ SOUR\r\n";
	$tuser = getUser($CONTACT_EMAIL);
	if ($tuser) {
		$filetext .= "1 AUTH ".$tuser["fullname"]."\r\n";
	}
	$filetext .= "1 TITL ".$HOME_SITE_TEXT."\r\n";
	$filetext .= "1 ABBR ".$HOME_SITE_TEXT."\r\n";
	$filetext .= "1 PUBL ".$HOME_SITE_URL."\r\n";
	$filetext .= "0 TRLR\r\n";
	$_SESSION["clippings"] = $filetext;
	print "\r\n\t<br /><br />".$pgv_lang["download"]."<br /><br /><ul><li>GEDCOM File:</li><ul><li><a href=\"clippings_download.php\">clipping.ged</a></li></ul>";
	if ($mediacount>0) {
		// -- create zipped media file
		print "<li>".$pgv_lang["media_files"]."</li><ul>";
		for($m=0; $m<$mediacount; $m++) {
			print "<li><a href=\"".$MEDIA_DIRECTORY."$media[$m]\">$media[$m]</a></li>";
		}
		print "</ul>";
	}
	print "</ul><br /><br />";
}
$ct = count($cart);
if($ct==0) {
	print "\r\n\t\t<br /><br />".$pgv_lang["cart_is_empty"]."<br /><br />";
}
else {
	print "\r\n\t<table class=\"list_table\">\r\n\t\t<tr>\r\n\t\t\t<td class=\"list_label\">".$pgv_lang["type"]."</td><td class=\"list_label\">".$pgv_lang["id"]."</td><td class=\"list_label\">".$pgv_lang["name_description"]."</th><td class=\"list_label\">".$pgv_lang["remove"]."</td>\r\n\t\t</tr>";
	for($i=0; $i<$ct; $i++) {
		print "\r\n\t\t<tr>\r\n\t\t<td class=\"list_value\">";
		$clipping = $cart[$i];
		if($clipping['type']=='indi') print "<img src=\"$PGV_IMAGE_DIR/$PGV_INDIS_IMG\" border=\"0\">";
		else if($clipping['type']=='fam') print "<img src=\"$PGV_IMAGE_DIR/$PGV_SFAMILY_IMG\" border=\"0\">";
		else if($clipping['type']=='source') print "<img src=\"$PGV_IMAGE_DIR/$PGV_SOURCE_IMG\" border=\"0\">";
		print "</td><td class=\"list_value\">".$clipping['id']."</td><td class=\"list_value\">";
		if($clipping['type']=='indi') print "<a href=\"individual.php?pid=".$clipping['id']."\">".get_sortable_name($clipping['id'])."</a>";
		else if($clipping['type']=='fam') print "<a href=\"family.php?famid=".$clipping['id']."\">".get_family_descriptor($clipping['id'])."</a>";
		else if($clipping['type']=='source') print "<a href=\"source.php?sid=".$clipping['id']."\">".get_source_descriptor($clipping['id'])."</a>";
		print "</td><td class=\"list_value\"><a href=\"clippings.php?action=remove&item=$i\">".$pgv_lang["remove"]."</a>\r\n\t\t</tr>";
	}
	print "\r\n\t</table>";
	print "\r\n\t<br /><a href=\"clippings.php?action=empty\">".$pgv_lang["empty_cart"]."</a>";
	if ($action != 'download') print "\r\n\t<br /><br /><a href=\"clippings.php?action=download\">".$pgv_lang["download_now"]."</a>";
}
if (isset($_SESSION["cart"])) $_SESSION["cart"]=$cart;
print_footer();
?>
