<?php
/*=================================================
	Project: phpGedView
	File: index.php
	Author: John Finlay
	Input Variables: $rootid
	Comments:
		Parses gedcom file and displays a pedigree tree.  Specify a $rootid to
		root the pedigree tree at a certain person with id = $rootid in the
		GEDCOM file.

	Change Log:
		5/30/02 - File Created
		6/12/02 - Fixed Netscape 6 popup div problem - Darn you netscape ;-)
					 - Added ability to change the spacing between the boxes in the
					 - config file.
		6/18/02 - Added user ability to specify border color on boxes
		9/24/02 - Added support for language files
		12/10/02 - Added better multiple spouse support
		1/28/03 - fixed for safe mode

	phpGedView: Genealogy Viewer
    Copyright (C) 2002 to 2003  John Finlay and Others

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
===================================================*/
// -- include config file
require("config.php");
require($PGV_BASE_DIRECTORY.$factsfile["english"]);
require($PGV_BASE_DIRECTORY.$factsfile[$LANGUAGE]);

$show_famlink = true;
if ((isset($view))&&($view=="preview")) {
	$baseyoffset=-10;
	$show_famlink = false;
}

if (!isset($show_full)) $show_full=$PEDIGREE_FULL_DETAILS;
if ($show_full=="") $show_full = 0;

if ((!isset($PEDIGREE_GENERATIONS))||($PEDIGREE_GENERATIONS=="")) $PEDIGREE_GENERATIONS=$DEFAULT_PEDIGREE_GENERATIONS;

if ($PEDIGREE_GENERATIONS > $MAX_PEDIGREE_GENERATIONS) {
	$PEDIGREE_GENERATIONS = $MAX_PEDIGREE_GENERATIONS;
}

//-- if the $rootid is not already there then find the first person in the file and make him the root
if (empty($rootid)) {
	$user = getUser(getUserName());
	if ((!empty($user["rootid"][$GEDCOM]))&&(find_person_record($user["rootid"][$GEDCOM]))) $rootid=$user["rootid"][$GEDCOM];
	else if ((!empty($user["gedcomid"][$GEDCOM]))&&(find_person_record($user["gedcomid"][$GEDCOM]))) $rootid=$user["gedcomid"][$GEDCOM];
	//-- allow users to overide default id in the config file.
	else if ((isset($PEDIGREE_ROOT_ID))&&(find_person_record($PEDIGREE_ROOT_ID)!="")) $rootid=$PEDIGREE_ROOT_ID;
	else {
		$rootid = find_first_person();
	}
}
else {
	if (preg_match("/[A-Za-z]+/", $rootid)==0) $rootid = $GEDCOM_ID_PREFIX.$rootid;
}

if ($USE_RIN) {
	$indirec = find_person_record($rootid);
	if ($indirec==false) $rootid = find_rin_id($rootid);
}
if ((DisplayDetailsByID($rootid))||(showLivingNameByID($rootid))) $name = get_person_name($rootid);
else $name = $pgv_lang["private"];

// -- print html header information
print_header($name." ".$pgv_lang["index_header"]);
print "\n\t<div class=\"pedigree_form\" style=\"position: absolute; top: ".($baseyoffset+30)."px; left: ".($basexoffset+10)."px;\"><h2>".$name."<br />".str_replace("#PEDIGREE_GENERATIONS#", $PEDIGREE_GENERATIONS, $pgv_lang["gen_ped_chart"])."</h2>";

// -- print the form to change the number of displayed generations
if ($view!="preview") {
	?>
	<script type="text/javascript">
	<!--
	var pasteto;
	function open_find(textbox) {
		pasteto = textbox;
		findwin = window.open('findid.php', '', 'left=50,top=50,width=450,height=450,resizable=1,scrollbars=1');
	}
	function paste_id(value) {
		pasteto.value=value;
	}
	//-->
	</script>
	<?php
	print "\n\t<form name=\"people\" method=\"get\" action=\"index.php\">\n\t\t".$pgv_lang["root_person"]."<input type=\"text\" name=\"rootid\" size=\"3\" value=\"$rootid\" /><font size=\"1\"><a href=\"javascript:open_find(document.people.rootid);\">".$pgv_lang["find_id"]."</a></font><br />";
	print "\n\t\t".$pgv_lang["generations"]." <select name=\"PEDIGREE_GENERATIONS\" onchange=\"document.people.submit();\">\n";
	for ($p=3; $p<=$MAX_PEDIGREE_GENERATIONS; $p++) {
	 	print "<option value=\"$p\"";
		if ($PEDIGREE_GENERATIONS==$p) print " selected=\"selected\"";
		print ">$p</option>\n";
	}
	print "</select> <br />\n\t\t<input type=\"submit\" value=\"".$pgv_lang["view"]."\" />";
	print "<input type=\"hidden\" name=\"show_full\" value=\"$show_full\" />";
	print "<input type=\"submit\" value=\"";
	if ($show_full) print $pgv_lang["hide_details"]."\" onclick=\"document.people.show_full.value='0';\" />\n";
	else print $pgv_lang["show_details"]."\" onclick=\"document.people.show_full.value='1';\" />\n";
	print "\n\t\t</form>";
}
print "</div>\n";

if ($show_full==false) {
	$bheight=25;
	$bwidth-=40;
	$baseyoffset+=125;
}

$pbwidth = $bwidth;
$pbheight = $bheight-1;
$pbwidth = $bwidth+6;
$pbheight = $bheight+5;

if ($PEDIGREE_GENERATIONS < 4) {
	$baseyoffset+=((4-$PEDIGREE_GENERATIONS)*$pbheight);
}

// -- the $treeid array will hold all of the individual ids to be displayed on the pedigree chart
// -- the id in position 0 is the root person.  The other positions are filled according to the following algorithm
// -- if an individual is at position $i then individual $i's father will occupy position ($i*2)+1 and $i's mother
// -- will occupy ($i*2)+2
$treeid = array();
$treeid[0]=$rootid;
// -- maximum size of the id array is 2^$PEDIGREE_GENERATIONS - 1
$treesize = pow(2, (int)($PEDIGREE_GENERATIONS))-1;
// -- fill in the id array
for($i=0; $i<($treesize/2); $i++) {
	if ($treeid[$i]) {
		print " ";
		$famids = find_family_ids($treeid[$i]);
		if (count($famids)>0) {
			$parents=false;
			$j=0;
			while((!$parents)&&($j<count($famids))) {
				$parents = find_parents($famids[$j]);
				$j++;
			}

			if ($parents) {
				$treeid[($i*2)+1]=$parents["HUSB"];		// -- set father id
				$treeid[($i*2)+2]=$parents["WIFE"];		// -- set mother id
			}
		}
		else {
			$treeid[($i*2)+1]=false;		// -- father not found
			$treeid[($i*2)+2]=false;		// -- mother not found
		}
	}
	else {
		$treeid[($i*2)+1]=false;		// -- father not found
		$treeid[($i*2)+2]=false;		// -- mother not found
	}
}

// -- this next section will create and position the DIV layers for the pedigree tree
$curgen = 1;			// -- variable to track which generation the algorithm is currently working on
$yoffset=0;				// -- used to offset the position of each box as it is generated
$xoffset=0;
$prevyoffset=0;		// -- used to track the y position of the previous box
// -- loop through all of id's in the array starting at the last and working to the first
for($i=($treesize-1); $i>=0; $i--) {
	// -- check to see if we have moved to the next generation
	if ($i < floor($treesize / (pow(2, $curgen)))) {
		$curgen++;
	}
	$prevyoffset = $yoffset;
	// -- calculate the yoffset				Position in the generation											Spacing between boxes										put child between parents
	$yoffset = $baseyoffset+(($i-pow(2, $PEDIGREE_GENERATIONS-$curgen)) * (($pbheight+$byspacing) * pow(2, $curgen-1)))+((($pbheight+$byspacing)/2)*pow(2,$curgen-1))+(($pbheight+$byspacing) * pow(2, $curgen-1));
	// -- calculate the xoffset
	$xoffset = 20+$basexoffset+ (($PEDIGREE_GENERATIONS - $curgen) * ($pbwidth+$bxspacing));
	// -- if we are in the middle generations then we need to draw the connecting lines
	if (($curgen >2) && ($curgen < $PEDIGREE_GENERATIONS)) {
		if ($i %2 ==1) {
			if ($SHOW_EMPTY_BOXES || ($treeid[$i]) || ($treeid[$i+1])) {
				print "<div id=\"line$i\" style=\"position:absolute; left:".($xoffset-1)."px; top:".($yoffset+$pbheight/2)."px; \">";
				print "<img src=\"$PGV_IMAGE_DIR/$PGV_VLINE_IMG\" width=\"3\" height=\"".($prevyoffset-$yoffset)."\" alt=\"\" />";
				print "</div>";
			}
		}
	}
	// -- draw the box
	if (!empty($treeid[$i]) || $SHOW_EMPTY_BOXES) {
		$widthadd = 0;
		if (($curgen==1)&&(find_family_id($treeid[$i]))) $widthadd = 20;
		if (($curgen >2) && ($curgen < $PEDIGREE_GENERATIONS)) $widthadd = 10;
		print "\n\t\t<div id=\"box";
		if (empty($treeid[$i])) print "$i";
		else print $treeid[$i];
		print "\" style=\"position:absolute; left:".$xoffset."px; top:".$yoffset."px; width:".($pbwidth+$widthadd)."px; height:".$pbheight."px; z-index: 0;\">";
		print "\n\t\t\t<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" width=\"100%\" dir=\"ltr\">";
		if (($curgen >2) && ($curgen < $PEDIGREE_GENERATIONS)) {
			print "<tr><td>";
			print "\n\t\t\t<img src=\"$PGV_IMAGE_DIR/$PGV_HLINE_IMG\" align=\"left\" hspace=\"0\" vspace=\"0\" alt=\"\" />";
			print "\n\t\t\t</td><td width=\"100%\" dir=\"$TEXT_DIRECTION\">";
		}
		else print "<tr><td width=\"100%\" dir=\"$TEXT_DIRECTION\">";
		$mfstyle = "";
		if (!empty($treeid[$i])) {
			$indirec = find_person_record($treeid[$i]);
			$ct = preg_match("/1 SEX F/", $indirec);
			if ($ct>0) $mfstyle="F";
		}
		print_pedigree_person($treeid[$i], 1, $show_famlink);
		if (($curgen==1)&&(find_family_id($treeid[$i]))) {
			$did = 1;
			if ($i > ($treesize/2) + ($treesize/4)-1) $did++;
			print "\n\t\t\t\t</td><td valign=\"middle\">";
			if ($view!="preview") print "<a href=\"index.php?PEDIGREE_GENERATIONS=$PEDIGREE_GENERATIONS&amp;rootid=".$treeid[$did]."&amp;show_full=$show_full\" onmouseover=\"swap_image('arrow$i',1);\" onmouseout=\"swap_image('arrow$i',1);\">";
			print "<img id=\"arrow$i\" src=\"$PGV_IMAGE_DIR/$PGV_RARROW_IMG\" border=\"0\" alt=\"\"/>";
			if ($view!="preview") print "</a>";
		}
		print "\n\t\t\t</td></tr></table>\n\t\t</div>";
	}
}

$indirec = find_person_record($rootid);
if (displayDetails($indirec) || showLivingName($indirec)) {
	// -- print left arrow for decendants so that we can move down the tree
	$yoffset += ($pbheight / 2)-10;
	$famids = find_sfamily_ids($rootid);
	if ($famids) {
		print "\n\t\t<div id=\"childarrow\" style=\"position:absolute; left:".$basexoffset."px; top:".$yoffset."px; width:10px; height:10px; \">";
		if ($view!="preview") print "<a href=\"#\" onclick=\"return togglechildrenbox();\" onmouseover=\"swap_image('larrow',0);\" onmouseout=\"swap_image('larrow',0);\">";
		print "<img id=\"larrow\" src=\"$PGV_IMAGE_DIR/$PGV_LARROW_IMG\" border=\"0\" alt=\"\" />";
		if ($view!="preview") print "</a>";
		print "\n\t\t</div>";
		$yoffset += ($pbheight / 2)+10;
		print "\n\t\t<div id=\"childbox\" style=\"position: absolute; left:".$xoffset."px; top:".$yoffset."px; width:".$pbwidth."px; height:".$pbheight."px; visibility: hidden;\">";
		print "\n\t\t\t<table class=\"person_box\"><tr><td>";
		for($f=0; $f<count($famids); $f++) {
			$famrec = find_family_record($famids[$f]);
			if ($famrec) {
				$parents = find_parents($famids[$f]);
				if($parents) {
					if($rootid!=$parents["HUSB"]) $spid=$parents["HUSB"];
					else $spid=$parents["WIFE"];
					print "\n\t\t\t\t<a href=\"index.php?PEDIGREE_GENERATIONS=$PEDIGREE_GENERATIONS&amp;rootid=$spid&amp;show_full=$show_full\"><font class=\"name1\">";
					if (displayDetailsById($spid) || showLivingNameById($spid)) {
						$name = get_person_name($spid);
						$name = rtrim($name);
						print $name;
					}
					else print $pgv_lang["living"];
					print "<br /></font></a>";

				}
				$num = preg_match_all("/1\s*CHIL\s*@(.*)@/", $famrec, $smatch,PREG_SET_ORDER);
				for($i=0; $i<$num; $i++) {
					$pid = $smatch[$i][1];
					print "\n\t\t\t\t&nbsp;&nbsp;<a href=\"index.php?PEDIGREE_GENERATIONS=$PEDIGREE_GENERATIONS&amp;rootid=$pid&amp;show_full=$show_full\"><font class=\"name1\">&lt; ";
					if (displayDetailsById($pid) || showLivingNameById($pid)) {
						$name = get_person_name($pid);
						$name = rtrim($name);
						print $name;
					}
					else print $pgv_lang["living"];
					print "<br /></font></a>";
				}
			}
		}
		$famids = find_family_ids($rootid);
		for($f=0; $f<count($famids); $f++) {
			$famrec = find_family_record($famids[$f]);
			if ($famrec) {
				$num = preg_match_all("/1\s*CHIL\s*@(.*)@/", $famrec, $smatch,PREG_SET_ORDER);
				if ($num>1) print "<font class=\"name1\"><br />".$pgv_lang["siblings"]."<br /></font>";
				for($i=0; $i<$num; $i++) {
					$pid = $smatch[$i][1];
					if ($pid!=$rootid) {
						print "\n\t\t\t\t&nbsp;&nbsp;<a href=\"index.php?PEDIGREE_GENERATIONS=$PEDIGREE_GENERATIONS&amp;rootid=$pid&amp;show_full=$show_full\"><font class=\"name1\"> ";
						if (displayDetailsById($pid) || showLivingNameById($pid)) {
							$name = get_person_name($pid);
							$name = rtrim($name);
							print $name;
						}
						else print $pgv_lang["living"];
						print "<br /></font></a>";
					}
				}
			}
		}
		print "\n\t\t\t</td></tr></table>";
		print "\n\t\t</div>";
	}
}
// -- print html footer
$yoffset = ($yoffset*2)-($baseyoffset)+25;
print "\n\t\t<div id=\"footerbox\" style=\"position:absolute; left:0px; top:".$yoffset."px; width:100%; z-index: '-11'; \">";
$without_close=true;
print_footer();
print "\n\t</div>\n</body>\n</html>";


?>
